type Platform = "darwin" | "win32";
interface DesktopWindow {
    title: string;
    rawContents: string;
    domain?: string;
    selectedText?: string;
}
/**
 * A third party application running on the user's computer.
 * @todo consider making focusedWindow an optional parameter,
 * add additional windows as an array
 */
interface DesktopApplication {
    name: string;
    focusedWindow: DesktopWindow;
}
/**
 * Details about the Highlight app environment, like the version.
 */
interface HighlightEnvironment {
    version: string;
    requestType?: string;
}
/**
 * Details about the environment that the user is currently in, such as the operating system.
 */
interface DesktopEnvironment {
    platform: Platform;
    /**
     * The scanned OCR contents of the user's entire screen.
     */
    ocrScreenContents?: string;
    screenshotPath?: string;
    clipboardText?: string;
    /**
     * @todo (Julian) make this required, it's not because it would break too much rn with context-orchestrator
     */
    highlight?: HighlightEnvironment;
}
/**
 * The base context that is available to all prompts.
 */
interface BasePromptContext {
    environment: DesktopEnvironment;
}
/**
 * A more modern context object that seperates the foregrounded application
 * and the environment in which Highlight is running.
 */
interface HighlightContext extends BasePromptContext {
    application: DesktopApplication;
    environment: DesktopEnvironment;
    /**
     * A string that represents the user's intent with the context of the application.
     */
    userIntent?: string;
    /**
     * An array of tasks that the user has performed.
     */
    previousTasks?: string[];
    /**
     * An array of strings for each "added" app, aka an app that has been enabled
     */
    addedApps?: string[];
    /**
     * An array of strings for each (added) app that has been pinned to the sidebar
     */
    pinnedApps?: string[];
    /**
     * An array of strings for each added app that is *not* pinned to the sidebar
     */
    addedUnpinnedApps?: string[];
}
interface HighlightHarmonyContext extends HighlightContext {
    /**
     * The action the user is performing.
     */
    actionLine: string;
    /**
     * The app ID of the application that Highlight will open (google, chatgpt, etc.)
     */
    appId: string;
    /**
     * Whether the app is an LLM type app. (eg: perplexity, chatgpt, etc.)
     */
    appIsLLMType: boolean;
    /**
     * A summary of the user's previous actions.
     */
    previousActionsSummary: string;
    /**
     * Last 2 hours of audio recording
     */
    audioLong: string;
    /**
     * Last 30 seconds of audio recording
     */
    audioRecent: string;
    /**
     * Context from VectorDB
     */
    /**
     * A list of facts that the user has added to the application.
     */
    factsAboutMe: string;
}

type HighlightEvent = "onContext";

interface HighlightAPI {
    user: {
        /**
         * Get the facts the user has set for themselves. This could be "I only want concise responses", "my name is...", etc.
         */
        getFacts: () => Promise<string[]>;
        /**
         * Get the audio captions from the user's device.
         * @param {boolean} longAudio - If you want to get the long audio captions. Fetch ASR text for the last 2 hours
         * @returns {string} - The audio captions.
         */
        getAudio: (longAudio: boolean) => Promise<string>;
        getScreenshot: () => Promise<string>;
        /**
         * Get an email address for the user, for privacy, this address will forward to the user's real email address.
         * @returns {string} - The email address.
         */
        getEmail: () => Promise<string>;
    };
    auth: {
        /**
         * Get an access token and refresh token that can be used to validate the user's session on your backend.
         */
        signIn: () => Promise<{
            accessToken: string;
            refreshToken: string;
        }>;
    };
    /**
     * Adds an event listener for your Highlight app.
     * @param event The name of the event to listen for.
     * @param listener The listener Highlight will call when the event is emitted.
     */
    addEventListener: (event: HighlightEvent, listener: (...args: any[]) => void) => void;
}
declare const api: HighlightAPI;

export { type BasePromptContext, type DesktopApplication, type DesktopEnvironment, type DesktopWindow, type HighlightContext, type HighlightEnvironment, type HighlightEvent, type HighlightHarmonyContext, type Platform, api as default };
